[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

SF.net SVN: ledger-smb:[3884] branches/1.3/LedgerSMB/Sysconfig.pm



Revision: 3884
          http://ledger-smb.svn.sourceforge.net/ledger-smb/?rev=3884&view=rev
Author:   einhverfr
Date:     2011-10-18 06:35:54 +0000 (Tue, 18 Oct 2011)
Log Message:
-----------
Re-enabling LaTeX paths in Sysconfig after a fix that I believe will correct Louis Moore's bug report

Modified Paths:
--------------
    branches/1.3/LedgerSMB/Sysconfig.pm

Modified: branches/1.3/LedgerSMB/Sysconfig.pm
===================================================================
--- branches/1.3/LedgerSMB/Sysconfig.pm	2011-10-18 05:54:39 UTC (rev 3883)
+++ branches/1.3/LedgerSMB/Sysconfig.pm	2011-10-18 06:35:54 UTC (rev 3884)
@@ -114,20 +114,16 @@
     ${$var} = $config{''}{$var} if $config{''}{$var};
 }
 
-# Commenting out the block below due to Louis Moore's bug report on the email 
-# lists.  It isn't clear what's causing this, and I'd rather not push out 
-# something that cuases issues for others without getting to the bottom of the 
-# issue.  Will re-activate these lines after 1.3.1 is released.
 
-#if ($latex){
-#    eval { require Template::Latex }; # Trap errors loading this optional module
-#    if ($!) { # Couldn't load  Template::Latex
-#        print STDERR "WARNING: LedgerSMB configured to use LaTeX but module ";
-#        print STDERR "Template::Latex did not load: ..hidden..";
-#        print STDERR "Disabling LaTeX support\n";
-#        $latex = 0;
-#    };
-#}
+if ($latex){
+    eval { require Template::Latex }; # Trap errors loading this optional module
+    if ($!) { # Couldn't load  Template::Latex
+        print STDERR "WARNING: LedgerSMB configured to use LaTeX but module ";
+        print STDERR "Template::Latex did not load: ..hidden..";
+        print STDERR "Disabling LaTeX support\n";
+        $latex = 0;
+    };
+}
 
 %printer = %{ $config{printers} } if $config{printers};
 
@@ -152,15 +148,12 @@
 
 # LaTeX and friends 
 #
-# Disabling these lines due to Louis Moore's bug report.  Will re-enable after
-# 1.3.1 is released so we have more time to check these out. --CT
-#
-#for my $var (qw(pdflatex latex dvips)){
-#    if ($latex and $config{programs}{$var}){
-#        my $funcname = "${var}_path";
-#        Template::Latex->$funcname( { $var => $config{programs}{$var} });
-#    }
-#}
+for my $var (qw(pdflatex latex dvips)){
+    if ($latex and $config{programs}{$var}){
+        my $funcname = "${var}_path";
+        Template::Latex->$funcname( { $var => $config{programs}{$var} });
+    }
+}
 
 # mail configuration
 for my $var (qw(sendmail smtphost smtptimeout smtpuser 

This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.